# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorarch: %global perl_vendorarch %(eval "`perl -V:installvendorarch`"; echo $installvendorarch)}

# In practice, this module is only actually used as a dependency of
# MIME::Tools, which requires MIME::Base64 ≥ 3.03. So I don't build it
# for distributions including MIME::Base64 ≥ 3.03.

Summary:	Encode/decode Base 64 (RFC 2045)
Name:		perl-MIME-XBase64
Version:	3.13
Release:	2.%{__distinit}%{__distvers}
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/MIME-Base64/
Source:		http://search.cpan.org/CPAN/authors/id/G/GA/GAAS/MIME-Base64-%{version}.tar.gz
Buildroot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	perl(ExtUtils::MakeMaker), perl(MIME::Base64)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
The module MIME::XBase64 is exactly the same as the MIME::Base64 module,
but is renamed so as to be able to coexist with the distribution-supplied
version of MIME::Base64, which is often too low a version to be usable,
but cannot be upgraded because it is part of the main perl package.

%prep
%setup -q -n MIME-Base64-%{version}

# See if there's any point building this module (no point if distro version ≥ this version)
found_mb64_version=$(perl -MMIME::Base64 -e 'print $MIME::Base64::VERSION;')
if [ $(expr $found_mb64_version '>=' %{version}) = '1' ]; then
	echo "MIME::Base64 on system ($found_mb64_version) is up to date;" \
		"no need for MIME::XBase64" 1>&2
	exit 1
fi

# Munge MIME::Base64 into MIME::XBase64
mv Base64.xs XBase64.xs
mv Base64.pm XBase64.pm
mv QuotedPrint.pm XQuotedPrint.pm
for f in XBase64.pm XBase64.xs Makefile.PL XQuotedPrint.pm t/*.t
do
	sed -i -e 's/MIME::Base64/MIME::XBase64/g' -e 's/MIME::QuotedPrint/MIME::XQuotedPrint/g' $f
done
sed -i -e 's/^Base64\./XBase64./g' -e 's/^QuotedPrint\.pm/XQuotedPrint.pm/' MANIFEST
sed -i -e 's/Base64\.pm/XBase64.pm/' Makefile.PL

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install PERL_INSTALL_ROOT=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
find %{buildroot} -depth -type d -exec rmdir {} ';' 2>/dev/null
chmod -R u+w %{buildroot}

%check
make test

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes README*
%{perl_vendorarch}/MIME/XBase64.pm
%{perl_vendorarch}/MIME/XQuotedPrint.pm
%{perl_vendorarch}/auto/MIME/XBase64/
%{_mandir}/man3/MIME::XBase64.3pm*
%{_mandir}/man3/MIME::XQuotedPrint.3pm*

%changelog
* Tue Oct 18 2011 Paul Howarth <paul@city-fan.org> 3.13-2
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Sat Nov 27 2010 Paul Howarth <paul@city-fan.org> 3.13-1
- Update to 3.13
  - The fix in v3.12 to try to preserve the SvUTF8 flag was buggy and actually
    managed to set the flag on strings that did not have it originally

* Fri Nov 26 2010 Paul Howarth <paul@city-fan.org> 3.12-1
- Update to 3.12
  - Don't change SvUTF8 flag on the strings encoded (CPAN RT#60105)
  - Documentation tweaks

* Thu Nov 25 2010 Paul Howarth <paul@city-fan.org> 3.11-1
- Update to 3.11
  - Provide encode_base64url and decode_base64url functions to process the
    base64 scheme for "URL applications"
  - decode_base64() does not issue warnings on suspect input data any more

* Fri Nov 12 2010 Paul Howarth <paul@city-fan.org> 3.10-1
- Update to 3.10 (provide functions to calculate the length of encoded and
  decoded base64 strings - CPAN RT#62404)

* Tue Jan 26 2010 Paul Howarth <paul@city-fan.org> 3.09-1
- Update to 3.09 (the Quoted-Printable encoder would sometimes output lines
  that were 77 characters long - the max line length should be 76 [RT#53919])
- Dist tag for Rawhide no longer needs special-casing

* Wed Jun 10 2009 Paul Howarth <paul@city-fan.org> 3.08-1
- Update to 3.08 (EBCDIC changes from core / Get rid of the PERL_CORE hacks)
- Update to SLES-compatible dist tag macros

* Sun Nov  2 2008 Paul Howarth <paul@city-fan.org> 3.07-3
- Tweak dist tag macros to work on current Rawhide with three-part releasenum
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)
- Fix argument order for find with -depth
- BuildRequire ExtUtils::MakeMaker

* Thu Aug 31 2006 Paul Howarth <paul@city-fan.org> 3.07-2
- Disregard distribution sub-release number in dist tag
- Define %%{__id_u} in a more portable way
- Don't do rpm database queries during build

* Fri Dec  2 2005 Paul Howarth <paul@city-fan.org> 3.07-1
- Update to 3.07
- Remove buildroot unconditionally in %%clean and %%install
- Use search.cpan.org URLs
- Don't use macros in paths for build-time commands, hardcode them instead
- Simplify distribution-detection
- Simplify compiler optimization flag settings
- Utility scripts no longer included

* Fri May 27 2005 Paul Howarth <paul@city-fan.org> 3.05-2
- Rewrite spec file in (mainly) Fedora Extras style
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Remove MANIFEST from %%doc
- Add build-time check to see if module is actually needed

* Tue Oct 26 2004 Paul Howarth <paul@city-fan.org> 3.05
- Initial RPM build
